"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const command_1 = require("@oclif/command");
//const next = require('next')
const next = require("next");
const axios_1 = require("axios");
var Mixpanel = require('mixpanel');
class Run extends command_1.Command {
    constructor() {
        super(...arguments);
        this.df_session_id = Math.random();
        this.mixpanel = Mixpanel.init('0a2a173a8daecb5124492f9d319ca429', {
            protocol: 'https'
        });
    }
    async run() {
        this.mixpanel.track('botonic_input');
        const { args, flags } = this.parse(Run);
        const path = flags.path ? path_1.resolve(flags.path) : process.cwd();
        this.conf = require(path_1.join(path, '/.next/botonic.config.js'));
        process.chdir(path);
        this.app = next({ dev: false });
        let input = args.input;
        if (input.type == 'text') {
            axios_1.default({
                headers: {
                    Authorization: 'Bearer ' + this.conf.integrations.dialogflow.token
                },
                url: 'https://api.dialogflow.com/v1/query',
                params: {
                    query: input.data, lang: 'en', sessionId: this.df_session_id
                }
            }).then((r) => {
                input.intent = r.data.result.action;
                this.processInput(input);
            }, (err) => console.log(err));
        }
        else {
            this.processInput(input);
        }
    }
    processInput(input) {
        let component = this.getRoute(input);
        const req = { headers: {}, method: 'GET', url: component };
        const res = {};
        const pathname = component;
        const query = {};
        this.app.renderToHTML(req, res, pathname, query, {}).then((html) => {
            console.log(html);
        });
    }
    getRoute(route) {
        for (var i = 0; i < this.conf.routes.length; i++) {
            let r = this.conf.routes[i];
            if ((route.type == 'text' && r.text == route.data) ||
                ((route.type == 'text' || route.type == 'postback') && route.payload && r.payload == route.payload) ||
                (route.intent && r.intent == route.intent)) {
                return this.conf.routes[i].component;
            }
        }
        return '';
    }
}
Run.description = 'Get response from a single input';
Run.examples = [
    `$ botonic input "{\"type\": \"text\", \"data\": \"hi\"}"
Hello!
`,
];
Run.flags = {
    // flag with a value (-n, --name=VALUE)
    path: command_1.flags.string({ char: 'p', description: 'Path to botonic project. Defaults to current dir.' })
};
Run.args = [{ name: 'input', parse: JSON.parse }];
exports.default = Run;
