"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
//import dynamic from 'next/dynamic'
const cheerio_1 = require("cheerio");
const Table = require("cli-table2");
const inquirer_1 = require("inquirer");
const colors = require("colors");
const axios_1 = require("axios");
const chalk_1 = require("chalk");
var Mixpanel = require('mixpanel');
class Run extends command_1.Command {
    constructor() {
        super(...arguments);
        this.df_session_id = Math.random();
        this.mixpanel = Mixpanel.init('0a2a173a8daecb5124492f9d319ca429', {
            protocol: 'https'
        });
    }
    async run() {
        this.mixpanel.track('botonic_run');
        const c = chalk_1.default.hex('#DEADED');
        console.log(c('Hey there, thanks for giving ')
            + c.bold('Botonic')
            + c(' a try!'));
        console.log("We're still developing the first version of Botonic, which is not available yet.");
        console.log("\nWould you like to contribute or send some feedback?\nJust drop us an email at " + chalk_1.default.bold("hi@botonic.io"));
        return;
        /*const {args, flags} = this.parse(Run)
        const path = flags.path? resolve(flags.path) : process.cwd()
        this.conf = require(join(path, '/.next/botonic.config.js'))
        process.chdir(path)
        this.app = next({ dev: false })
        this.chat_loop()*/
    }
    chat_loop() {
        inquirer_1.prompt([{
                type: 'input',
                name: 'input',
                message: '[user]>'
            }]).then((inp) => {
            let input = { type: 'text', 'data': inp.input };
            if (inp.input.startsWith('!')) {
                input = { type: 'postback', 'payload': inp.input.slice(1) };
                this.processInput(input);
            }
            else {
                axios_1.default({
                    headers: {
                        Authorization: 'Bearer ' + this.conf.integrations.dialogflow.token
                    },
                    url: 'https://api.dialogflow.com/v1/query',
                    params: {
                        query: inp.input, lang: 'en', sessionId: this.df_session_id
                    }
                }).then((r) => {
                    input.intent = r.data.result.action;
                    this.processInput(input);
                }, (err) => console.log(err));
            }
        });
    }
    processInput(input) {
        let component = this.getRoute(input);
        const req = { headers: {}, method: 'GET', url: component };
        const res = {};
        const pathname = component;
        const query = {};
        this.app.renderToHTML(req, res, pathname, query, {}).then((html) => {
            this.parseOutput(html);
            this.chat_loop();
        });
    }
    getRoute(route) {
        for (var i = 0; i < this.conf.routes.length; i++) {
            let r = this.conf.routes[i];
            if ((route.type == 'text' && r.text == route.data) ||
                ((route.type == 'text' || route.type == 'postback') && route.payload && r.payload == route.payload) ||
                (route.intent && r.intent == route.intent)) {
                return this.conf.routes[i].component;
            }
        }
        return '';
    }
    parseOutput(output) {
        let html = cheerio_1.load(output);
        let outputs = html('[type=text], [type=carrousel]')
            .map((i, elem) => {
            let el = html(elem);
            let out = '';
            if (el.is('[type=text]')) {
                out = el.contents().filter(e => el.contents()[e].type === 'text').text().trim();
            }
            else if (el.is('[type=carrousel]')) {
                const c = new Table({
                    style: { head: [], border: [] },
                    wordWrap: false
                });
                let cards = [];
                el.find('element').slice(0, 3).each((j, e) => {
                    let te = new Table({ style: { head: [], border: [] } });
                    let el = html(e);
                    let buttons = el.find('button')
                        .map((k, b) => html(b).text() + '\n(' + html(b).attr('href') + ')')
                        .get();
                    te.push([el.find('title').text() + '\n\n' + el.find('desc').text()], buttons);
                    cards.push(te.toString());
                });
                if (el.find('element').length > 3)
                    cards.push({
                        content: '...\n(' + (el.find('element').length - 3) + ' more elements)',
                        vAlign: 'center',
                        hAlign: 'center'
                    });
                c.push(cards);
                out = '\n' + c.toString();
            }
            let keyboard = '';
            if (el.find('reply').length > 0) {
                let kt = new Table({ style: { head: [], border: [] } });
                let keys = el.find('reply')
                    .map((i, e) => html(e).text() + '\n(' + html(e).attr('payload') + ')')
                    .get();
                kt.push(keys);
                keyboard = '\n' + kt.toString();
            }
            if (out)
                return '  [bot]> ' + out + keyboard;
        })
            .get();
        console.log(colors.magenta(outputs.join('\n')));
    }
}
Run.description = 'Start interactive session';
Run.examples = [
    `$ botonic run
Your bot is ready, start talking:
[you] > Hi
[bot] > Bye!
`,
];
Run.flags = {
    // flag with a value (-n, --name=VALUE)
    path: command_1.flags.string({ char: 'p', description: 'Path to botonic project. Defaults to current dir.' })
};
Run.args = [{ name: 'input', parse: JSON.parse }];
exports.default = Run;
